@@ -235,10 +235,10 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
                 title = f'[{website.name}]-{landingForm.email_subject}'
             
             
-            from django.template import Context
+            from django.template import RequestContext
             mail = get_template('blog_extension/call_to_action/FileConfirm.txt').template
             
-            message = mail.render(Context(replaceStr))
+            message = mail.render(RequestContext(request,replaceStr))
             send_mail(
                 title,
                 message,
@@ -316,8 +316,9 @@ def showTargetFile(request):
                 settings.MEDIA_URL + \
                 str(callToActionStatistics.action.targetFile.file)
 
-            response = serve(request, path, document_root=settings.BASE_DIR)
-            return response
+            # response = serve(request, path, document_root=settings.BASE_DIR)
+            path = settings.MEDIA_URL + str(callToActionStatistics.action.targetFile.file)
+            return redirect(path)
 
         elif callToActionStatistics.action.linkUrl:
             return render(
@@ -328,16 +329,20 @@ def showTargetFile(request):
 
         else:
             domain = Site.objects.get_current().domain
+            websiteName = Site.objects.get_current().name
             
             slug = callToActionStatistics.url.split('/')[-2]
             article = Article.objects.filter(translations__slug=slug)
             if article:
                 article = article[0]
                 articleId = int_to_hashid(article.pk)
-                fileName = f'[{domain}]{article.slug}.pdf'
-                path = settings.MEDIA_URL[1:] + PDF_ROOT + fileName
+                fileName = f'[{websiteName}]{article.slug}.pdf'
+                path = settings.MEDIA_URL + PDF_ROOT + fileName
+                
                 try:
-                    pdfkit.from_url(settings.META_SITE_PROTOCOL + '://' + domain + reverse('renderArticle', kwargs={'articleId': articleId}), path)
+                    
+                    pdfkit.from_url(settings.META_SITE_PROTOCOL + '://' + domain + reverse('renderArticle', 
+                                    kwargs={'articleId': articleId}), path[1:])
 
                 # might occur as the https is at risk
                 # the file(img or any file on site) is loaded successfully
@@ -361,16 +366,16 @@ def showTargetFile(request):
                 fileName = f"{title}.pdf"
 
 
-                path = settings.MEDIA_URL[1:] + PDF_ROOT + fileName
+                path = settings.MEDIA_URL + PDF_ROOT + fileName
 
 
                 pdfkit.from_url(
                     f"{settings.META_SITE_PROTOCOL}://{domain}{callToActionStatistics.url}",
-                    path,
+                    path[1:],
                 )
-            response = serve(request, path, document_root=settings.BASE_DIR)
+            # response = serve(request, path, document_root=settings.BASE_DIR)
 
-            return response
+            return redirect(path)
 
     key = request.GET.get('key')
     if request.POST.get('token'):
