@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 12088 2020-04-17 09:49:03Z Lavender $
+# $Id: setup.py 12104 2020-04-23 05:57:59Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-17 17:49:03 +0800 (週五, 17 四月 2020) $
-# $Revision: 12088 $
+# $Date: 2020-04-23 14:57:59 +0900 (週四, 23 四月 2020) $
+# $Revision: 12104 $
 
 import re
 import os
@@ -59,7 +59,7 @@ logger.addHandler(handler)
 
 INTRODUCTION_URL = "https://www.django-cms-themes.com/static/docs"
 SETUP_URL = "https://www.django-cms-themes.com/static/product/assets/setup.py"
-SETUP_VERSION = "1.0.0"
+SETUP_VERSION = "1.0.1"
 SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
 CKEDITOR_SETTINGS = \
 '''
@@ -679,11 +679,14 @@ if __name__ == "__main__":
             settingsPath = findSettings(path)
         else:
             path = os.path.dirname(os.path.dirname(settingsPath))
-       
-        settingModule = os.path.splitext(settingsPath[len(path) + 1:])[0]
+        
+        if len(path) == 0:
+            settingModule = os.path.splitext(settingsPath)[0]
+        else:
+            settingModule = os.path.splitext(settingsPath[len(path) + 1:])[0]
         settingModule = settingModule.replace("/", ".")
         settingModule = settingModule.replace("\\", ".")
-       
+        
         sys.path.append(path)
         os.environ['DJANGO_SETTINGS_MODULE'] = settingModule        
         
@@ -793,6 +796,9 @@ if __name__ == "__main__":
             print("")
             logger.error(
                 colored("Please check the project's db was migrated.", "red"))
+            logger.error(
+                colored("If you encounter \"Could not load xxxxx: UNIQUE constraint failed\","
+                        " this is because your project already has CMS data.", "red"))
             sendLog({
                 "level": "ERROR",
                 "error": traceback.format_exc(),
