@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11977 2020-03-16 18:37:48Z Lavender $
+# $Id: __init__.py 12107 2020-04-23 08:17:04Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-17 02:37:48 +0800 (週二, 17 三月 2020) $
-# $Revision: 11977 $
+# $Date: 2020-04-23 17:17:04 +0900 (週四, 23 四月 2020) $
+# $Revision: 12107 $
 
 import json
 import requests
@@ -32,8 +32,8 @@ else:
 
 class Settings(object):
     # Facebook Nuwa Blog APP
-    ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1251674698332603"#"1435073943305111"
-    ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "d1467e0724e3c46749de6413366bb12e" #"1f0ba7a626695ee0c5419627c2d0a8b9"
+    ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
+    ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
     ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN = "25025529"
     
     ZEPHYRUS_FACEBOOK_FAN_DEFAULT_TEMPLATE = \
