@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12011 2020-03-25 11:01:56Z Lavender $
+# $Id: views.py 12044 2020-04-05 11:36:35Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-25 19:01:56 +0800 (週三, 25 三月 2020) $
-# $Revision: 12011 $
+# $Date: 2020-04-05 20:36:35 +0900 (週日, 05 四月 2020) $
+# $Revision: 12044 $
 
 import json
 
@@ -28,11 +28,14 @@ from django.conf import settings
 from django.utils.translation import ugettext as _
 from django.urls import reverse
 
+from Iuppiter.Logging import createLogger
 from Zephyrus.facebook import MANAGE_PAGES_STATE
 from Zephyrus.facebook import settings as FBSettings
 from Zephyrus.facebook import getCommentURL, getAPIData
 from Zephyrus.facebook.models import APIData, FacebookSettings
 
+logger = createLogger(__name__)
+
 def createAuthorizationURL(request, scope=["manage_pages", "pages_show_list"], state=MANAGE_PAGES_STATE):
     scope = ",".join(scope)
     redirectUrl = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
@@ -77,10 +80,13 @@ class FacebookAuthorizationView(View):
                     config, created = FacebookSettings.objects.get_or_create()
                     config.accessToken = accessToken
                     config.save()
+                    logger.info("Success get access token from facebook API: %s" % data)
                     msg = _("Authorization successfully, this window will close automatically.")
                 else:
+                    logger.error("Can't get access token from facebook API: %s" % data)
                     msg = _("Authorization failed, please try again. This window will close automatically.")
             except Exception as e:
+                logger.error("Can't get access token from facebook API: %s" % e)
                 msg = _("Authorization failed, please try again. This window will close automatically.")
             return render(request, "facebook/Authorization.html", {"msg": msg,})
         raise Http404()
